@@ -14,7 +14,7 @@ module Spec
           @output.flush
         end
       
-        def example_pending(example_group_description, example, message)
+        def example_pending(example, message)
           super
           @output.print yellow('P')
           @output.flush
@@ -24,6 +24,10 @@ module Spec
           @output.puts
           @output.flush
         end
+        
+        def method_missing(sym, *args)
+          # ignore
+        end
       end
     end
   end
